import { Pipe, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const isArray = (value) => Array.isArray(value);
const isFunction = (value) => typeof value === 'function';
const isNil = (value) => value === null || typeof value === 'undefined';
const isNull = (value) => value === null;
const isNumber = (value) => typeof value === 'number';
const isObject = (value) => typeof value === 'object';
const isString = (value) => typeof value === 'string';
const isUndefined = (value) => typeof value === 'undefined';
/**
 * @param {?} object
 * @return {?}
 */
function toArray(object) {
    return isArray(object) ? object : Object.keys(object).map((key) => object[key]);
}
const getPhone = (locale) => {
    const /** @type {?} */ phones = {
        'en-US': {
            'countryCode': '+1',
            'minLength': 10,
            'pattern': /^(\+?1[-\s]?)?(\(?\d{3}\)?)[-\s]?(\d{3})[-\s]?(\d{4})$/
        },
        'pt-BR': {
            'countryCode': '+55',
            'minLength': 11,
            'pattern': /^(\+?55[-\s]?)?(\([1-9][1-9]\)|[1-9][1-9])[-\s]?(9[1-9]\d{3})[-\s]?(\d{4})$/
        }
    };
    return phones[locale];
};
const pad = (requiredLength, padChar = ' ') => padChar.repeat(requiredLength).slice(0, requiredLength);
/**
 * @param {?} a
 * @param {?} b
 * @return {?}
 */
function equals(a, b) {
    if (a === b) {
        return true;
    }
    if (!isObject(a) || !isObject(b)) {
        return a === b;
    }
    const /** @type {?} */ keysA = Object.keys(a);
    const /** @type {?} */ keysB = Object.keys(b);
    if (keysA.length !== keysB.length) {
        return false;
    }
    // Test for A's keys different from B.
    const /** @type {?} */ hasOwn = Object.prototype.hasOwnProperty;
    for (const /** @type {?} */ key of keysA) {
        if (!hasOwn.call(b, key) || !equals(a[key], b[key])) {
            return false;
        }
    }
    return true;
}
/**
 * @param {?} partial
 * @param {?} object
 * @return {?}
 */
function objectContains(partial, object) {
    return Object.keys(partial).every((key) => key in object && object[key] === partial[key]);
}
/**
 * @param {?} obj
 * @param {?=} stack
 * @param {?=} parent
 * @param {?=} intermediate
 * @return {?}
 */
function deepKeys(obj, stack = [], parent = null, intermediate = false) {
    Object.keys(obj).forEach((el) => {
        // Escape . in the element name
        const /** @type {?} */ escaped = el.replace(/\./g, '\\\.');
        // If it's a nested object
        if (isObject(obj[el]) && !isArray(obj[el])) {
            // Concatenate the new parent if exist
            const /** @type {?} */ p = parent ? parent + '.' + el : parent;
            // Push intermediate parent key if flag is true
            if (intermediate)
                stack.push(parent ? p : escaped);
            deepKeys(obj[el], stack, p || escaped, intermediate);
        }
        else {
            // Create and save the key
            const /** @type {?} */ key = parent ? parent + '.' + escaped : escaped;
            stack.push(key);
        }
    });
    return stack;
}
/**
 * \@description
 * return the first n element of an array,
 * if expression provided, is returns as long the expression return truthy
 * @param {?} array
 * @param {?} n {number}
 * @param {?} getter
 * @return {?} array or single object
 */
function getFirstMatches(array, n, getter) {
    let /** @type {?} */ count = 0;
    return array.filter((elm) => {
        const /** @type {?} */ rest = !isUndefined(getter) ? count < n && getter(elm) : count < n;
        count = rest ? count + 1 : count;
        return rest;
    });
}
/**
 * \@description
 * search for approximate pattern in string
 * @param {?} word
 * @param {?} pattern
 * @return {?}
 */
function hasApproxPattern(word, pattern) {
    let /** @type {?} */ p = 0;
    for (let /** @type {?} */ i = 0; i <= pattern.length; i++) {
        const /** @type {?} */ index = indexOf(word, p, pattern.charAt(i));
        if (index === -1)
            return false;
        p += index + 1;
    }
    return true;
}
/**
 * @param {?} word
 * @param {?} p
 * @param {?} c
 * @return {?}
 */
function indexOf(word, p, c) {
    let /** @type {?} */ j = 0;
    while ((p + j) <= word.length) {
        if (word.charAt(p + j) === c)
            return j;
        j++;
    }
    return -1;
}
const convertToDecimal = (num, decimal) => {
    return Math.round(num * Math.pow(10, decimal)) / (Math.pow(10, decimal));
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsArrayPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isArray(input);
    }
}
IsArrayPipe.decorators = [
    { type: Pipe, args: [{ name: 'isArray' },] },
];
/** @nocollapse */
IsArrayPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsDefinedPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return !isUndefined(input);
    }
}
IsDefinedPipe.decorators = [
    { type: Pipe, args: [{ name: 'isDefined' },] },
];
/** @nocollapse */
IsDefinedPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsEqualToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        input += '';
        check += '';
        return input === check;
    }
}
IsEqualToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isEqualTo' },] },
];
/** @nocollapse */
IsEqualToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsFunctionPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isFunction(input);
    }
}
IsFunctionPipe.decorators = [
    { type: Pipe, args: [{ name: 'isFunction' },] },
];
/** @nocollapse */
IsFunctionPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsGreaterThanOrEqualToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return input >= check;
    }
}
IsGreaterThanOrEqualToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isGreaterThanOrEqualTo' },] },
];
/** @nocollapse */
IsGreaterThanOrEqualToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsGreaterThanPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return input > check;
    }
}
IsGreaterThanPipe.decorators = [
    { type: Pipe, args: [{ name: 'isGreaterThan' },] },
];
/** @nocollapse */
IsGreaterThanPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsIdenticalToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return equals(input, check);
    }
}
IsIdenticalToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isIdenticalTo' },] },
];
/** @nocollapse */
IsIdenticalToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsLessThanOrEqualToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return input <= check;
    }
}
IsLessThanOrEqualToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isLessThanOrEqualTo' },] },
];
/** @nocollapse */
IsLessThanOrEqualToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsLessThanPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return input < check;
    }
}
IsLessThanPipe.decorators = [
    { type: Pipe, args: [{ name: 'isLessThan' },] },
];
/** @nocollapse */
IsLessThanPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsNilPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isNil(input);
    }
}
IsNilPipe.decorators = [
    { type: Pipe, args: [{ name: 'isNil' },] },
];
/** @nocollapse */
IsNilPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsNotEqualToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        input += '';
        check += '';
        return input !== check;
    }
}
IsNotEqualToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isNotEqualTo' },] },
];
/** @nocollapse */
IsNotEqualToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsNotIdenticalToPipe {
    /**
     * @param {?} input
     * @param {?} check
     * @return {?}
     */
    transform(input, check) {
        return !equals(input, check);
    }
}
IsNotIdenticalToPipe.decorators = [
    { type: Pipe, args: [{ name: 'isNotIdenticalTo' },] },
];
/** @nocollapse */
IsNotIdenticalToPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsNullPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isNull(input);
    }
}
IsNullPipe.decorators = [
    { type: Pipe, args: [{ name: 'isNull' },] },
];
/** @nocollapse */
IsNullPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsNumberPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isNumber(input);
    }
}
IsNumberPipe.decorators = [
    { type: Pipe, args: [{ name: 'isNumber' },] },
];
/** @nocollapse */
IsNumberPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsObjectPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isObject(input);
    }
}
IsObjectPipe.decorators = [
    { type: Pipe, args: [{ name: 'isObject' },] },
];
/** @nocollapse */
IsObjectPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsStringPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isString(input);
    }
}
IsStringPipe.decorators = [
    { type: Pipe, args: [{ name: 'isString' },] },
];
/** @nocollapse */
IsStringPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsUndefinedPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isUndefined(input);
    }
}
IsUndefinedPipe.decorators = [
    { type: Pipe, args: [{ name: 'isUndefined' },] },
];
/** @nocollapse */
IsUndefinedPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BooleanPipesModule {
}
BooleanPipesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    IsArrayPipe, IsDefinedPipe, IsEqualToPipe, IsFunctionPipe, IsGreaterThanOrEqualToPipe,
                    IsGreaterThanPipe, IsIdenticalToPipe, IsLessThanOrEqualToPipe, IsLessThanPipe, IsNilPipe,
                    IsNotEqualToPipe, IsNotIdenticalToPipe, IsNullPipe, IsNumberPipe, IsObjectPipe, IsStringPipe,
                    IsUndefinedPipe
                ],
                exports: [
                    IsArrayPipe, IsDefinedPipe, IsEqualToPipe, IsFunctionPipe, IsGreaterThanOrEqualToPipe,
                    IsGreaterThanPipe, IsIdenticalToPipe, IsLessThanOrEqualToPipe, IsLessThanPipe, IsNilPipe,
                    IsNotEqualToPipe, IsNotIdenticalToPipe, IsNullPipe, IsNumberPipe, IsObjectPipe, IsStringPipe,
                    IsUndefinedPipe
                ]
            },] },
];
/** @nocollapse */
BooleanPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AfterWherePipe {
    /**
     * @param {?} collection
     * @param {?} object
     * @return {?}
     */
    transform(collection, object) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        let /** @type {?} */ index = collection.map((e) => objectContains(object, e)).indexOf(true);
        return collection.slice(index === -1 ? 0 : index);
    }
}
AfterWherePipe.decorators = [
    { type: Pipe, args: [{ name: 'afterWhere' },] },
];
/** @nocollapse */
AfterWherePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AfterPipe {
    /**
     * @param {?} collection
     * @param {?=} count
     * @return {?}
     */
    transform(collection, count = 0) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return collection.slice(count);
    }
}
AfterPipe.decorators = [
    { type: Pipe, args: [{ name: 'after' },] },
];
/** @nocollapse */
AfterPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BeforeWherePipe {
    /**
     * @param {?} collection
     * @param {?} object
     * @return {?}
     */
    transform(collection, object) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        let /** @type {?} */ index = collection.map((e) => objectContains(object, e)).indexOf(true);
        return collection.slice(0, index === -1 ? collection.length : index + 1);
    }
}
BeforeWherePipe.decorators = [
    { type: Pipe, args: [{ name: 'beforeWhere' },] },
];
/** @nocollapse */
BeforeWherePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BeforePipe {
    /**
     * @param {?} collection
     * @param {?=} count
     * @return {?}
     */
    transform(collection, count = 1) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return collection.slice(0, count - 1);
    }
}
BeforePipe.decorators = [
    { type: Pipe, args: [{ name: 'before' },] },
];
/** @nocollapse */
BeforePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ChunkByPipe {
    /**
     * @param {?} array
     * @param {?} chunkSize
     * @param {?=} fillVal
     * @return {?}
     */
    transform(array, chunkSize, fillVal) {
        return array
            .map((el, i, self) => {
            i = i * chunkSize;
            el = self.slice(i, i + chunkSize);
            return !isUndefined(fillVal) && el.length < chunkSize ?
                el.concat(this.fill(chunkSize - el.length, fillVal)) :
                el;
        })
            .slice(0, Math.ceil(array.length / chunkSize));
    }
    /**
     * @param {?} chunkSize
     * @param {?} val
     * @return {?}
     */
    fill(chunkSize, val) {
        const /** @type {?} */ ret = [];
        while (chunkSize--)
            ret[chunkSize] = val;
        return ret;
    }
}
ChunkByPipe.decorators = [
    { type: Pipe, args: [{ name: 'chunkBy' },] },
];
/** @nocollapse */
ChunkByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ConcatPipe {
    /**
     * @param {?} collection
     * @param {?} joined
     * @return {?}
     */
    transform(collection, joined) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(joined)) {
            joined = toArray(joined);
        }
        return collection.concat(joined);
    }
}
ConcatPipe.decorators = [
    { type: Pipe, args: [{ name: 'concat' },] },
];
/** @nocollapse */
ConcatPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @param {?} pathKeys
 * @return {?}
 */
function createGetterFn(pathKeys) {
    let /** @type {?} */ fn = null;
    for (let /** @type {?} */ i = pathKeys.length - 1; i >= 0; i--) {
        if (fn === null) {
            fn = finalFn(pathKeys[i]);
        }
        else {
            fn = stepFn(pathKeys[i], fn);
        }
    }
    return fn;
    /**
     * @param {?} key
     * @return {?}
     */
    function finalFn(key) {
        return function (scope, local) {
            if (local && local.hasOwnProperty(key))
                return local[key];
            if (scope)
                return scope[key];
        };
    }
    /**
     * @param {?} key
     * @param {?} next
     * @return {?}
     */
    function stepFn(key, next) {
        return function (scope, local) {
            return next(scope && scope[key], local && local[key]);
        };
    }
}
/**
 * @param {?} scope
 * @param {?} path
 * @param {?} value
 * @return {?}
 */
function setterFn(scope, path, value) {
    let /** @type {?} */ s = scope;
    let /** @type {?} */ i = 0;
    for (; i < path.length - 1; i++) {
        if (isUndefined(s[path[i]]) && i < path.length - 1) {
            s[path[i]] = {};
        }
        s = s[path[i]];
    }
    s[path[i]] = value;
    return scope;
}
/**
 * \@description
 * return parse function
 * @return {?}
 */
function Parse() {
    const /** @type {?} */ cache = {};
    return function (exp) {
        let /** @type {?} */ fn = function () { };
        if (isString(exp)) {
            const /** @type {?} */ cacheKey = exp.trim();
            if (cacheKey in cache) {
                return cache[cacheKey];
            }
            const /** @type {?} */ pathKeys = exp.split('.');
            fn = cache[cacheKey] = createGetterFn(pathKeys);
            fn.assign = function (scope, value) {
                return setterFn(scope, pathKeys, value);
            };
        }
        else if (isFunction(exp)) {
            fn = function (scope, local) {
                return exp(scope, local);
            };
        }
        return fn;
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ContainsPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        return collection.some((e) => isFunction(predicate) || (isString(predicate) && isObject(e)) ?
            this.$parse(predicate)(e) :
            e === predicate);
    }
}
ContainsPipe.decorators = [
    { type: Pipe, args: [{ name: 'contains' },] },
];
/** @nocollapse */
ContainsPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CountByPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        let /** @type {?} */ result = {}, /** @type {?} */ getter = this.$parse(predicate);
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        collection.forEach((elm) => {
            let /** @type {?} */ prop = getter(elm);
            if (!(prop in result))
                result[prop] = 0;
            result[prop]++;
        });
        return result;
    }
}
CountByPipe.decorators = [
    { type: Pipe, args: [{ name: 'countBy' },] },
];
/** @nocollapse */
CountByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DefaultsPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} defaults
     * @return {?}
     */
    transform(collection, defaults) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        let /** @type {?} */ getters = deepKeys(defaults).map((key) => this.$parse(key));
        collection.forEach((elm) => {
            getters.forEach((getter) => {
                if (isUndefined(getter(elm))) {
                    getter.assign(elm, getter(defaults));
                }
            });
        });
        return collection;
    }
}
DefaultsPipe.decorators = [
    { type: Pipe, args: [{ name: 'defaults' },] },
];
/** @nocollapse */
DefaultsPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EveryPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        return collection.every((e) => isFunction(predicate) || (isString(predicate) && isObject(e)) ?
            this.$parse(predicate)(e) :
            e === predicate);
    }
}
EveryPipe.decorators = [
    { type: Pipe, args: [{ name: 'every' },] },
];
/** @nocollapse */
EveryPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FilterByPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} properties
     * @param {?=} search
     * @param {?=} strict
     * @return {?}
     */
    transform(collection, properties, search, strict = false) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        search = isString(search) || isNumber(search) ? String(search).toLowerCase() : undefined;
        if (!isArray(collection) || isUndefined(search)) {
            return collection;
        }
        if (isString(search) || isNumber(search)) {
            search = String(search).toLowerCase();
        }
        return collection.filter((elm) => {
            return properties.some((prop) => {
                /**
                 * check if there are concatenate properties
                 * example:
                 * object: { first: 'foo', last:'bar' }
                 * filterBy: ['first + last'] => search by full name(i.e 'foo bar')
                 */
                let /** @type {?} */ comparator;
                if (!~prop.indexOf('+')) {
                    comparator = this.$parse(prop)(elm);
                }
                else {
                    let /** @type {?} */ propList = prop.replace(/\s+/g, '').split('+');
                    comparator = propList.map((p) => this.$parse(p)(elm)).join(' ');
                }
                // TODO: boolean?
                if (!isString(comparator) && !isNumber(comparator)) {
                    return false;
                }
                comparator = String(comparator).toLowerCase();
                // indentical or contains
                return strict ? comparator === search : comparator.indexOf(search) !== -1;
            });
        });
    }
}
FilterByPipe.decorators = [
    { type: Pipe, args: [{ name: 'filterBy' },] },
];
/** @nocollapse */
FilterByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FirstPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {...?} args
     * @return {?}
     */
    transform(collection, ...args) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        let /** @type {?} */ n = isNumber(args[0]) ? args[0] : 1, /** @type {?} */
        getter = !isNumber(args[0]) ? args[0] : !isNumber(args[1]) ? args[1] : undefined;
        return args.length ? getFirstMatches(collection, n, getter ? this.$parse(getter) : getter) :
            collection[0];
    }
}
FirstPipe.decorators = [
    { type: Pipe, args: [{ name: 'first' },] },
];
/** @nocollapse */
FirstPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FlattenPipe {
    /**
     * @param {?} collection
     * @param {?=} shallow
     * @return {?}
     */
    transform(collection, shallow = false) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return shallow ? [].concat.apply([], collection) : this.flatten(collection);
    }
    /**
     * @param {?} array
     * @return {?}
     */
    flatten(array) {
        return array.reduce((arr, elm) => elm instanceof Array ? arr.concat(this.flatten(elm)) : arr.concat(elm), []);
    }
}
FlattenPipe.decorators = [
    { type: Pipe, args: [{ name: 'flatten' },] },
];
/** @nocollapse */
FlattenPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FuzzyByPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} property
     * @param {?=} search
     * @param {?=} csensitive
     * @return {?}
     */
    transform(collection, property, search, csensitive = false) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection) || isUndefined(search)) {
            return collection;
        }
        let /** @type {?} */ getter = this.$parse(property);
        return collection.filter((elm) => {
            let /** @type {?} */ prop = getter(elm);
            if (!isString(prop)) {
                return false;
            }
            if (!csensitive) {
                prop = prop.toLowerCase();
                search = search.toLowerCase();
            }
            return hasApproxPattern(prop, search) !== false;
        });
    }
}
FuzzyByPipe.decorators = [
    { type: Pipe, args: [{ name: 'fuzzyBy' },] },
];
/** @nocollapse */
FuzzyByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FuzzyPipe {
    /**
     * @param {?} collection
     * @param {?} search
     * @param {?=} csensitive
     * @return {?}
     */
    transform(collection, search, csensitive = false) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection) || isUndefined(search)) {
            return collection;
        }
        if (!csensitive) {
            search = search.toLowerCase();
        }
        return collection.filter((elm) => {
            if (isString(elm)) {
                if (!csensitive) {
                    elm = elm.toLowerCase();
                }
                return hasApproxPattern(elm, search);
            }
            return isObject(elm) ? this.hasApproximateKey(elm, search, csensitive) : false;
        });
    }
    /**
     * @param {?} object
     * @param {?} search
     * @param {?=} csensitive
     * @return {?}
     */
    hasApproximateKey(object, search, csensitive = false) {
        return Object.keys(object).some((elm) => {
            let /** @type {?} */ prop = object[elm];
            if (!isString(prop)) {
                return false;
            }
            if (!csensitive) {
                prop = prop.toLowerCase();
            }
            return hasApproxPattern(prop, search);
        });
    }
}
FuzzyPipe.decorators = [
    { type: Pipe, args: [{ name: 'fuzzy' },] },
];
/** @nocollapse */
FuzzyPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GroupByPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} property
     * @return {?}
     */
    transform(collection, property) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        let /** @type {?} */ result = {}, /** @type {?} */ getter = this.$parse(property);
        collection.forEach((elm) => {
            let /** @type {?} */ prop = getter(elm);
            if (isUndefined(result[prop])) {
                result[prop] = [];
            }
            result[prop].push(elm);
        });
        return result;
    }
}
GroupByPipe.decorators = [
    { type: Pipe, args: [{ name: 'groupBy' },] },
];
/** @nocollapse */
GroupByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IsEmptyPipe {
    /**
     * @param {?} collection
     * @return {?}
     */
    transform(collection) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        return isArray(collection) ? collection.length : 0;
    }
}
IsEmptyPipe.decorators = [
    { type: Pipe, args: [{ name: 'isEmpty' },] },
];
/** @nocollapse */
IsEmptyPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class JoinPipe {
    /**
     * @param {?} collection
     * @param {?=} delimiter
     * @return {?}
     */
    transform(collection, delimiter = ' ') {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        return collection.join(String(delimiter));
    }
}
JoinPipe.decorators = [
    { type: Pipe, args: [{ name: 'join' },] },
];
/** @nocollapse */
JoinPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LastPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {...?} args
     * @return {?}
     */
    transform(collection, ...args) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        collection = collection.slice().reverse();
        let /** @type {?} */ n = isNumber(args[0]) ? args[0] : 1, /** @type {?} */
        getter = !isNumber(args[0]) ? args[0] : !isNumber(args[1]) ? args[1] : undefined;
        return args.length
            // send reversed collection as arguments, and reverse it back
            ?
                getFirstMatches(collection, n, getter ? this.$parse(getter) : getter).reverse() :
            collection[0];
    }
}
LastPipe.decorators = [
    { type: Pipe, args: [{ name: 'last' },] },
];
/** @nocollapse */
LastPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MapPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return collection.map((e) => this.$parse(predicate)(e));
    }
}
MapPipe.decorators = [
    { type: Pipe, args: [{ name: 'map' },] },
];
/** @nocollapse */
MapPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MeanPipe {
    /**
     * @param {?} collection
     * @return {?}
     */
    transform(collection) {
        if (isNil(collection))
            return collection;
        let /** @type {?} */ arr = collection;
        if (!isArray(collection)) {
            arr = toArray(collection);
        }
        if (!isArray(arr) || arr.length === 0)
            return undefined;
        const /** @type {?} */ reduce = arr.reduce((prev, curr) => prev + curr, 0);
        return isNumber(reduce) ? reduce / arr.length : 0;
    }
}
MeanPipe.decorators = [
    { type: Pipe, args: [{ name: 'mean' },] },
];
/** @nocollapse */
MeanPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class OmitPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return collection.filter((e) => !this.$parse(predicate)(e));
    }
}
OmitPipe.decorators = [
    { type: Pipe, args: [{ name: 'omit' },] },
];
/** @nocollapse */
OmitPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class OrderByPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} array
     * @param {...?} attrs
     * @return {?}
     */
    transform(array, ...attrs) {
        // generate an array of predicate-objects contains
        // property getter, and descending indicator
        let /** @type {?} */ predicates = attrs.map(pred => {
            let /** @type {?} */ descending = pred.charAt(0) === '-' ? -1 : 1;
            pred = pred.replace(/^-/, '');
            return { getter: (o) => this.$parse(pred)(o), descend: descending };
        });
        // schwartzian transform idiom implementation. aka:
        // "decorate-sort-undecorate"
        return array
            .map(item => {
            return { src: item, compareValues: predicates.map(predicate => predicate.getter(item)) };
        })
            .sort((o1, o2) => {
            let /** @type {?} */ i = -1;
            let /** @type {?} */ result = 0;
            while (++i < predicates.length) {
                if (o1.compareValues[i] < o2.compareValues[i]) {
                    result = -1;
                }
                if (o1.compareValues[i] > o2.compareValues[i]) {
                    result = 1;
                }
                result *= predicates[i].descend;
                if (result) {
                    break;
                }
            }
            return result;
        })
            .map(item => item.src);
    }
}
OrderByPipe.decorators = [
    { type: Pipe, args: [{ name: 'orderBy' },] },
];
/** @nocollapse */
OrderByPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PickPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection)) {
            return collection;
        }
        return collection.filter((e) => this.$parse(predicate)(e));
    }
}
PickPipe.decorators = [
    { type: Pipe, args: [{ name: 'pick' },] },
];
/** @nocollapse */
PickPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RangePipe {
    /**
     * @param {?} input
     * @param {?=} total
     * @param {?=} start
     * @param {?=} increment
     * @param {?=} cb
     * @return {?}
     */
    transform(input, total = 0, start = 0, increment = 1, cb) {
        for (let /** @type {?} */ i = 0; i < total; i++) {
            const /** @type {?} */ j = start + i * increment;
            input.push(isFunction(cb) ? cb(j) : j);
        }
        return input;
    }
}
RangePipe.decorators = [
    { type: Pipe, args: [{ name: 'range' },] },
];
/** @nocollapse */
RangePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RemoveWithPipe {
    /**
     * @param {?} collection
     * @param {?=} object
     * @return {?}
     */
    transform(collection, object) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection) || isUndefined(object)) {
            return collection;
        }
        return collection.filter((e) => !objectContains(object, e));
    }
}
RemoveWithPipe.decorators = [
    { type: Pipe, args: [{ name: 'removeWith' },] },
];
/** @nocollapse */
RemoveWithPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RemovePipe {
    /**
     * @param {?} collection
     * @param {...?} args
     * @return {?}
     */
    transform(collection, ...args) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        return collection.filter((e) => {
            return !args.some((c) => equals(c, e));
        });
    }
}
RemovePipe.decorators = [
    { type: Pipe, args: [{ name: 'remove' },] },
];
/** @nocollapse */
RemovePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ReversePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        if (isString(input)) {
            return Array.from(input).reverse().join('');
        }
        return isArray(input) ? input.reverse() : input;
    }
}
ReversePipe.decorators = [
    { type: Pipe, args: [{ name: 'reverse' },] },
];
/** @nocollapse */
ReversePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SearchFieldPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {...?} args
     * @return {?}
     */
    transform(collection, ...args) {
        if (!isArray(collection) || !args.length) {
            return collection;
        }
        return collection.map((member) => {
            let /** @type {?} */ field = args.map((arg) => this.$parse(arg)(member)).join(' ');
            member.searchField = field;
            return member;
        });
    }
}
SearchFieldPipe.decorators = [
    { type: Pipe, args: [{ name: 'searchField' },] },
];
/** @nocollapse */
SearchFieldPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ToArrayPipe {
    /**
     * @param {?} collection
     * @param {?=} addKey
     * @return {?}
     */
    transform(collection, addKey = false) {
        if (!isObject(collection)) {
            return collection;
        }
        return addKey ? Object.keys(collection).map((key) => {
            // TODO: object.assign polyfill
            let /** @type {?} */ o = collection[key];
            o.$key = key;
            return o;
        }) :
            toArray(collection);
    }
}
ToArrayPipe.decorators = [
    { type: Pipe, args: [{ name: 'toArray' },] },
];
/** @nocollapse */
ToArrayPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class UniqPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} collection
     * @param {?=} predicate
     * @return {?}
     */
    transform(collection, predicate) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (isUndefined(predicate)) {
            return collection.filter((e, i, self) => self.indexOf(e) === i);
        }
        let /** @type {?} */ getter = this.$parse(predicate), /** @type {?} */ uniqueItems = [];
        return collection.filter((e) => {
            let /** @type {?} */ v = getter(e);
            if (!isUndefined(v) && uniqueItems.some((ue) => ue === v)) {
                return false;
            }
            uniqueItems.push(v);
            return true;
        });
    }
}
UniqPipe.decorators = [
    { type: Pipe, args: [{ name: 'uniq' },] },
];
/** @nocollapse */
UniqPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class WherePipe {
    /**
     * @param {?} collection
     * @param {?=} object
     * @return {?}
     */
    transform(collection, object) {
        if (!isArray(collection)) {
            collection = toArray(collection);
        }
        if (!isArray(collection) || isUndefined(object)) {
            return collection;
        }
        return collection.filter((e) => objectContains(object, e));
    }
}
WherePipe.decorators = [
    { type: Pipe, args: [{ name: 'where' },] },
];
/** @nocollapse */
WherePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class XORPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} col1
     * @param {?} col2
     * @param {?=} predicate
     * @return {?}
     */
    transform(col1, col2, predicate) {
        col1 = !isArray(col1) ? toArray(col1) : col1;
        col2 = !isArray(col2) ? toArray(col2) : col2;
        if (!isArray(col1) || !isArray(col2)) {
            return col1;
        }
        return col1.concat(col2).filter((elm) => {
            return !(this.some(elm, col1, predicate) && this.some(elm, col2, predicate));
        });
    }
    /**
     * @param {?} el
     * @param {?} col
     * @param {?=} predicate
     * @return {?}
     */
    some(el, col, predicate) {
        let /** @type {?} */ getter = this.$parse(predicate);
        return col.some((dElm) => {
            if (isUndefined(predicate)) {
                return dElm === el;
            }
            return getter(dElm) === getter(el);
        });
    }
}
XORPipe.decorators = [
    { type: Pipe, args: [{ name: 'xor' },] },
];
/** @nocollapse */
XORPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CollectionPipesModule {
}
CollectionPipesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AfterWherePipe, BeforeWherePipe, AfterPipe, BeforePipe, ChunkByPipe, ConcatPipe,
                    ContainsPipe, CountByPipe, DefaultsPipe, EveryPipe, FilterByPipe, FirstPipe,
                    FlattenPipe, FuzzyByPipe, FuzzyPipe, GroupByPipe, IsEmptyPipe, JoinPipe,
                    LastPipe, MapPipe, MeanPipe, OmitPipe, PickPipe, RangePipe,
                    RemoveWithPipe, ReversePipe, SearchFieldPipe, RemovePipe, ToArrayPipe, UniqPipe,
                    WherePipe, XORPipe, OrderByPipe
                ],
                exports: [
                    AfterWherePipe, BeforeWherePipe, AfterPipe, BeforePipe, ChunkByPipe, ConcatPipe,
                    ContainsPipe, CountByPipe, DefaultsPipe, EveryPipe, FilterByPipe, FirstPipe,
                    FlattenPipe, FuzzyByPipe, FuzzyPipe, GroupByPipe, IsEmptyPipe, JoinPipe,
                    LastPipe, MapPipe, MeanPipe, OmitPipe, PickPipe, RangePipe,
                    RemoveWithPipe, ReversePipe, SearchFieldPipe, RemovePipe, ToArrayPipe, UniqPipe,
                    WherePipe, XORPipe, OrderByPipe
                ]
            },] },
];
/** @nocollapse */
CollectionPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AbsPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return Math.abs(Number(input));
    }
}
AbsPipe.decorators = [
    { type: Pipe, args: [{ name: 'abs' },] },
];
/** @nocollapse */
AbsPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ByteFmtPipe {
    constructor() {
        this.compared = [{ str: 'B', val: 1024 }];
        ['KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'].forEach((el, i) => {
            this.compared.push({ str: el, val: this.compared[i].val * 1024 });
        });
    }
    /**
     * @param {?} bytes
     * @param {?} decimal
     * @return {?}
     */
    transform(bytes, decimal) {
        if (isNumber(decimal) && isFinite(decimal) && decimal % 1 === 0 && decimal >= 0 &&
            isNumber(bytes) && isFinite(bytes)) {
            let /** @type {?} */ i = 0;
            while (i < this.compared.length - 1 && bytes >= this.compared[i].val)
                i++;
            bytes /= i > 0 ? this.compared[i - 1].val : 1;
            return convertToDecimal(bytes, decimal) + ' ' + this.compared[i].str;
        }
        return 'NaN';
    }
}
ByteFmtPipe.decorators = [
    { type: Pipe, args: [{ name: 'byteFmt' },] },
];
/** @nocollapse */
ByteFmtPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CeilPipe {
    /**
     * @param {?} input
     * @param {?=} precision
     * @return {?}
     */
    transform(input, precision = 0) {
        const /** @type {?} */ num = parseFloat(input);
        const /** @type {?} */ prec = parseInt(precision, 10);
        if (isNaN(num))
            return input;
        if (isNaN(prec) || prec <= 0) {
            return Math.ceil(num);
        }
        else {
            const /** @type {?} */ pow = Math.pow(10, precision);
            return Math.ceil(num * pow) / pow;
        }
    }
}
CeilPipe.decorators = [
    { type: Pipe, args: [{ name: 'ceil' },] },
];
/** @nocollapse */
CeilPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DegreesPipe {
    /**
     * @param {?} radians
     * @param {?} decimal
     * @return {?}
     */
    transform(radians, decimal) {
        // if decimal is not an integer greater than -1, we cannot do. quit with
        // error "NaN"
        // if degrees is not a real number, we cannot do also. quit with error "NaN"
        if (isNumber(decimal) && isFinite(decimal) && decimal % 1 === 0 && decimal >= 0 &&
            isNumber(radians) && isFinite(radians)) {
            const /** @type {?} */ degrees = (radians * 180) / Math.PI;
            return Math.round(degrees * Math.pow(10, decimal)) / (Math.pow(10, decimal));
        }
        else {
            return NaN;
        }
    }
}
DegreesPipe.decorators = [
    { type: Pipe, args: [{ name: 'degrees' },] },
];
/** @nocollapse */
DegreesPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FloorPipe {
    /**
     * @param {?} input
     * @param {?=} precision
     * @return {?}
     */
    transform(input, precision = 0) {
        const /** @type {?} */ num = parseFloat(input);
        const /** @type {?} */ prec = parseInt(precision, 10);
        if (isNaN(num))
            return input;
        if (isNaN(prec) || prec <= 0) {
            return Math.floor(num);
        }
        else {
            const /** @type {?} */ pow = Math.pow(10, precision);
            return Math.floor(num * pow) / pow;
        }
    }
}
FloorPipe.decorators = [
    { type: Pipe, args: [{ name: 'floor' },] },
];
/** @nocollapse */
FloorPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class KBFmtPipe {
    constructor() {
        this.compared = [{ str: 'KB', val: 1024 }];
        ['MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'].forEach((el, i) => {
            this.compared.push({ str: el, val: this.compared[i].val * 1024 });
        });
    }
    /**
     * @param {?} bytes
     * @param {?} decimal
     * @return {?}
     */
    transform(bytes, decimal) {
        if (isNumber(decimal) && isFinite(decimal) && decimal % 1 === 0 && decimal >= 0 &&
            isNumber(bytes) && isFinite(bytes)) {
            let /** @type {?} */ i = 0;
            while (i < this.compared.length - 1 && bytes >= this.compared[i].val)
                i++;
            bytes /= i > 0 ? this.compared[i - 1].val : 1;
            return convertToDecimal(bytes, decimal) + ' ' + this.compared[i].str;
        }
        return 'NaN';
    }
}
KBFmtPipe.decorators = [
    { type: Pipe, args: [{ name: 'kbFmt' },] },
];
/** @nocollapse */
KBFmtPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MaxPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} input
     * @param {?=} predicate
     * @return {?}
     */
    transform(input, predicate) {
        return isUndefined(predicate) ? Math.max.apply(Math, input) :
            input[this.index(input, this.$parse(predicate))];
    }
    /**
     * @param {?} input
     * @param {?} fn
     * @return {?}
     */
    index(input, fn) {
        const /** @type {?} */ mappedArray = input.map((elm) => fn(elm) || -Infinity);
        return mappedArray.indexOf(Math.max.apply(Math, mappedArray));
    }
}
MaxPipe.decorators = [
    { type: Pipe, args: [{ name: 'max' },] },
];
/** @nocollapse */
MaxPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MinPipe {
    constructor() {
        this.$parse = Parse();
    }
    /**
     * @param {?} input
     * @param {?=} predicate
     * @return {?}
     */
    transform(input, predicate) {
        return isUndefined(predicate) ? Math.min.apply(Math, input) :
            input[this.index(input, this.$parse(predicate))];
    }
    /**
     * @param {?} input
     * @param {?} fn
     * @return {?}
     */
    index(input, fn) {
        const /** @type {?} */ mappedArray = input.map((elm) => fn(elm) || Infinity);
        return mappedArray.indexOf(Math.min.apply(Math, mappedArray));
    }
}
MinPipe.decorators = [
    { type: Pipe, args: [{ name: 'min' },] },
];
/** @nocollapse */
MinPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PercentPipe {
    /**
     * @param {?} input
     * @param {?=} divided
     * @param {?=} round
     * @return {?}
     */
    transform(input, divided = 100, round = false) {
        let /** @type {?} */ divider = input;
        if (isString(input)) {
            divider = Number(input);
        }
        if (!isNumber(divider) || isNaN(divider)) {
            return input;
        }
        return round ? Math.round((divider / divided) * 100) : (divider / divided) * 100;
    }
}
PercentPipe.decorators = [
    { type: Pipe, args: [{ name: 'percent' },] },
];
/** @nocollapse */
PercentPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PowPipe {
    /**
     * @param {?} input
     * @param {?=} power
     * @return {?}
     */
    transform(input, power = 2) {
        const /** @type {?} */ num = parseFloat(input);
        const /** @type {?} */ parsed = parseInt(power, 10);
        if (isNaN(num))
            return input;
        return Math.pow(num, (isNaN(parsed)) ? 2 : parsed);
    }
}
PowPipe.decorators = [
    { type: Pipe, args: [{ name: 'pow' },] },
];
/** @nocollapse */
PowPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RadiansPipe {
    /**
     * @param {?} degrees
     * @param {?} decimal
     * @return {?}
     */
    transform(degrees, decimal) {
        // if decimal is not an integer greater than -1, we cannot do. quit with
        // error "NaN"
        // if degrees is not a real number, we cannot do also. quit with error "NaN"
        if (isNumber(decimal) && isFinite(decimal) && decimal % 1 === 0 && decimal >= 0 &&
            isNumber(degrees) && isFinite(degrees)) {
            const /** @type {?} */ radians = (degrees * 3.14159265359) / 180;
            return Math.round(radians * Math.pow(10, decimal)) / (Math.pow(10, decimal));
        }
        return NaN;
    }
}
RadiansPipe.decorators = [
    { type: Pipe, args: [{ name: 'radians' },] },
];
/** @nocollapse */
RadiansPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RadixPipe {
    /**
     * @param {?} input
     * @param {?} radix
     * @return {?}
     */
    transform(input, radix) {
        let /** @type {?} */ RANGE = /^[2-9]$|^[1-2]\d$|^3[0-6]$/;
        if (!isNumber(input) || !RANGE.test(radix.toString())) {
            return input.toString();
        }
        return input.toString(radix).toUpperCase();
    }
}
RadixPipe.decorators = [
    { type: Pipe, args: [{ name: 'radix' },] },
];
/** @nocollapse */
RadixPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RoundPipe {
    /**
     * @param {?} input
     * @param {?=} precision
     * @return {?}
     */
    transform(input, precision = 0) {
        const /** @type {?} */ num = parseFloat(input);
        const /** @type {?} */ prec = parseInt(precision, 10);
        if (isNaN(num))
            return input;
        if (isNaN(prec) || prec <= 0) {
            return Math.round(num);
        }
        else {
            const /** @type {?} */ pow = Math.pow(10, precision);
            return Math.round(num * pow) / pow;
        }
    }
}
RoundPipe.decorators = [
    { type: Pipe, args: [{ name: 'round' },] },
];
/** @nocollapse */
RoundPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ShortFmtPipe {
    /**
     * @param {?} number
     * @param {?} decimal
     * @return {?}
     */
    transform(number, decimal) {
        if (isNumber(decimal) && isFinite(decimal) && decimal % 1 === 0 && decimal >= 0 &&
            isNumber(number) && isFinite(number)) {
            if (number < 1e3) {
                return '' + number; // Coerce to string
            }
            else if (number < 1e6) {
                return convertToDecimal((number / 1e3), decimal) + ' K';
            }
            else if (number < 1e9) {
                return convertToDecimal((number / 1e6), decimal) + ' M';
            }
            else {
                return convertToDecimal((number / 1e9), decimal) + ' B';
            }
        }
        return 'NaN';
    }
}
ShortFmtPipe.decorators = [
    { type: Pipe, args: [{ name: 'shortFmt' },] },
];
/** @nocollapse */
ShortFmtPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SqrtPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        const /** @type {?} */ num = parseInt(input, 10);
        return isNaN(num) ? input : Math.sqrt(num);
    }
}
SqrtPipe.decorators = [
    { type: Pipe, args: [{ name: 'sqrt' },] },
];
/** @nocollapse */
SqrtPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SumPipe {
    /**
     * @param {?} array
     * @param {?=} initial
     * @return {?}
     */
    transform(array, initial = 0) {
        if (!isArray(array)) {
            return array;
        }
        return array.reduce(function (prev, curr) {
            return prev + curr;
        }, initial);
    }
}
SumPipe.decorators = [
    { type: Pipe, args: [{ name: 'sum' },] },
];
/** @nocollapse */
SumPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MathPipesModule {
}
MathPipesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AbsPipe, ByteFmtPipe, CeilPipe, KBFmtPipe, DegreesPipe, FloorPipe, MaxPipe, MinPipe,
                    PercentPipe, PowPipe, RadiansPipe, RadixPipe, RoundPipe, ShortFmtPipe, SumPipe, SqrtPipe
                ],
                exports: [
                    AbsPipe, ByteFmtPipe, CeilPipe, KBFmtPipe, DegreesPipe, FloorPipe, MaxPipe, MinPipe,
                    PercentPipe, PowPipe, RadiansPipe, RadixPipe, RoundPipe, ShortFmtPipe, SumPipe, SqrtPipe
                ]
            },] },
];
/** @nocollapse */
MathPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class InvertPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        if (isNil(input) || isArray(input) || !isObject(input))
            return input;
        const /** @type {?} */ newObj = {};
        for (const /** @type {?} */ obj in input) {
            if (!!!newObj[input[obj]]) {
                newObj[input[obj]] = [];
            }
            newObj[input[obj]].push(obj);
        }
        return newObj;
    }
}
InvertPipe.decorators = [
    { type: Pipe, args: [{ name: 'invert' },] },
];
/** @nocollapse */
InvertPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class KeysPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isNil(input) || isArray(input) || !isObject(input) ? input : Object.keys(input);
    }
}
KeysPipe.decorators = [
    { type: Pipe, args: [{ name: 'keys' },] },
];
/** @nocollapse */
KeysPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ValuesPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return isNil(input) || isArray(input) || !isObject(input) ?
            input :
            Object.keys(input).map(v => input[v]);
    }
}
ValuesPipe.decorators = [
    { type: Pipe, args: [{ name: 'values' },] },
];
/** @nocollapse */
ValuesPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ObjectPipesModule {
}
ObjectPipesModule.decorators = [
    { type: NgModule, args: [{ declarations: [InvertPipe, KeysPipe, ValuesPipe], exports: [InvertPipe, KeysPipe, ValuesPipe] },] },
];
/** @nocollapse */
ObjectPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CamelizePipe {
    /**
     * @param {?} input
     * @param {?=} upperFirst
     * @return {?}
     */
    transform(input, upperFirst = false) {
        if (!isString(input))
            return input;
        return input.toLowerCase()
            .split(/[-_\s]+/g)
            .filter(value => value !== '')
            .map((value, index) => index === 0 && !!!upperFirst ?
            value :
            `${value.substring(0, 1).toUpperCase() + value.substring(1)}`)
            .join('');
    }
}
CamelizePipe.decorators = [
    { type: Pipe, args: [{ name: 'camelize' },] },
];
/** @nocollapse */
CamelizePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CenterPadPipe {
    /**
     * @param {?} input
     * @param {?} requiredLength
     * @param {?=} padChar
     * @return {?}
     */
    transform(input, requiredLength, padChar = ' ') {
        if (!isString(input) || input.length >= requiredLength)
            return input;
        const /** @type {?} */ diff = requiredLength - input.length;
        const /** @type {?} */ left = Math.ceil(diff / 2);
        const /** @type {?} */ right = Math.floor(diff / 2);
        return `${pad(left, padChar)}${input}${pad(right, padChar)}`;
    }
}
CenterPadPipe.decorators = [
    { type: Pipe, args: [{ name: 'centerPad' },] },
];
/** @nocollapse */
CenterPadPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EndsWithPipe {
    /**
     * @param {?} input
     * @param {?=} ends
     * @param {?=} csensitive
     * @return {?}
     */
    transform(input, ends, csensitive = false) {
        if (ends === '') {
            return true;
        }
        if (!csensitive) {
            input = input.toLowerCase();
            ends = ends.toLowerCase();
        }
        return input.substring(input.length - ends.length) === ends;
    }
}
EndsWithPipe.decorators = [
    { type: Pipe, args: [{ name: 'endsWith' },] },
];
/** @nocollapse */
EndsWithPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LatinizePipe {
    constructor() {
        let /** @type {?} */ defaultDiacriticsRemovalap = [
            {
                'base': 'A',
                'letters': [
                    '\u0041', '\u24B6', '\uFF21', '\u00C0', '\u00C1', '\u00C2', '\u1EA6', '\u1EA4', '\u1EAA',
                    '\u1EA8', '\u00C3', '\u0100', '\u0102', '\u1EB0', '\u1EAE', '\u1EB4', '\u1EB2', '\u0226',
                    '\u01E0', '\u00C4', '\u01DE', '\u1EA2', '\u00C5', '\u01FA', '\u01CD', '\u0200', '\u0202',
                    '\u1EA0', '\u1EAC', '\u1EB6', '\u1E00', '\u0104', '\u023A', '\u2C6F'
                ]
            },
            { 'base': 'AA', 'letters': ['\uA732'] },
            { 'base': 'AE', 'letters': ['\u00C6', '\u01FC', '\u01E2'] },
            { 'base': 'AO', 'letters': ['\uA734'] },
            { 'base': 'AU', 'letters': ['\uA736'] },
            { 'base': 'AV', 'letters': ['\uA738', '\uA73A'] },
            { 'base': 'AY', 'letters': ['\uA73C'] },
            {
                'base': 'B',
                'letters': [
                    '\u0042', '\u24B7', '\uFF22', '\u1E02', '\u1E04', '\u1E06', '\u0243', '\u0182', '\u0181'
                ]
            },
            {
                'base': 'C',
                'letters': [
                    '\u0043', '\u24B8', '\uFF23', '\u0106', '\u0108', '\u010A', '\u010C', '\u00C7', '\u1E08',
                    '\u0187', '\u023B', '\uA73E'
                ]
            },
            {
                'base': 'D',
                'letters': [
                    '\u0044', '\u24B9', '\uFF24', '\u1E0A', '\u010E', '\u1E0C', '\u1E10', '\u1E12', '\u1E0E',
                    '\u0110', '\u018B', '\u018A', '\u0189', '\uA779'
                ]
            },
            { 'base': 'DZ', 'letters': ['\u01F1', '\u01C4'] },
            { 'base': 'Dz', 'letters': ['\u01F2', '\u01C5'] },
            {
                'base': 'E',
                'letters': [
                    '\u0045', '\u24BA', '\uFF25', '\u00C8', '\u00C9', '\u00CA', '\u1EC0', '\u1EBE',
                    '\u1EC4', '\u1EC2', '\u1EBC', '\u0112', '\u1E14', '\u1E16', '\u0114', '\u0116',
                    '\u00CB', '\u1EBA', '\u011A', '\u0204', '\u0206', '\u1EB8', '\u1EC6', '\u0228',
                    '\u1E1C', '\u0118', '\u1E18', '\u1E1A', '\u0190', '\u018E'
                ]
            },
            { 'base': 'F', 'letters': ['\u0046', '\u24BB', '\uFF26', '\u1E1E', '\u0191', '\uA77B'] },
            {
                'base': 'G',
                'letters': [
                    '\u0047', '\u24BC', '\uFF27', '\u01F4', '\u011C', '\u1E20', '\u011E', '\u0120', '\u01E6',
                    '\u0122', '\u01E4', '\u0193', '\uA7A0', '\uA77D', '\uA77E'
                ]
            },
            {
                'base': 'H',
                'letters': [
                    '\u0048', '\u24BD', '\uFF28', '\u0124', '\u1E22', '\u1E26', '\u021E', '\u1E24', '\u1E28',
                    '\u1E2A', '\u0126', '\u2C67', '\u2C75', '\uA78D'
                ]
            },
            {
                'base': 'I',
                'letters': [
                    '\u0049', '\u24BE', '\uFF29', '\u00CC', '\u00CD', '\u00CE', '\u0128',
                    '\u012A', '\u012C', '\u0130', '\u00CF', '\u1E2E', '\u1EC8', '\u01CF',
                    '\u0208', '\u020A', '\u1ECA', '\u012E', '\u1E2C', '\u0197'
                ]
            },
            { 'base': 'J', 'letters': ['\u004A', '\u24BF', '\uFF2A', '\u0134', '\u0248'] },
            {
                'base': 'K',
                'letters': [
                    '\u004B', '\u24C0', '\uFF2B', '\u1E30', '\u01E8', '\u1E32', '\u0136', '\u1E34', '\u0198',
                    '\u2C69', '\uA740', '\uA742', '\uA744', '\uA7A2'
                ]
            },
            {
                'base': 'L',
                'letters': [
                    '\u004C', '\u24C1', '\uFF2C', '\u013F', '\u0139', '\u013D', '\u1E36', '\u1E38', '\u013B',
                    '\u1E3C', '\u1E3A', '\u0141', '\u023D', '\u2C62', '\u2C60', '\uA748', '\uA746', '\uA780'
                ]
            },
            { 'base': 'LJ', 'letters': ['\u01C7'] },
            { 'base': 'Lj', 'letters': ['\u01C8'] },
            {
                'base': 'M',
                'letters': ['\u004D', '\u24C2', '\uFF2D', '\u1E3E', '\u1E40', '\u1E42', '\u2C6E', '\u019C']
            },
            {
                'base': 'N',
                'letters': [
                    '\u004E', '\u24C3', '\uFF2E', '\u01F8', '\u0143', '\u00D1', '\u1E44', '\u0147', '\u1E46',
                    '\u0145', '\u1E4A', '\u1E48', '\u0220', '\u019D', '\uA790', '\uA7A4'
                ]
            },
            { 'base': 'NJ', 'letters': ['\u01CA'] },
            { 'base': 'Nj', 'letters': ['\u01CB'] },
            {
                'base': 'O',
                'letters': [
                    '\u004F', '\u24C4', '\uFF2F', '\u00D2', '\u00D3', '\u00D4', '\u1ED2', '\u1ED0', '\u1ED6',
                    '\u1ED4', '\u00D5', '\u1E4C', '\u022C', '\u1E4E', '\u014C', '\u1E50', '\u1E52', '\u014E',
                    '\u022E', '\u0230', '\u00D6', '\u022A', '\u1ECE', '\u0150', '\u01D1', '\u020C', '\u020E',
                    '\u01A0', '\u1EDC', '\u1EDA', '\u1EE0', '\u1EDE', '\u1EE2', '\u1ECC', '\u1ED8', '\u01EA',
                    '\u01EC', '\u00D8', '\u01FE', '\u0186', '\u019F', '\uA74A', '\uA74C'
                ]
            },
            { 'base': 'OI', 'letters': ['\u01A2'] },
            { 'base': 'OO', 'letters': ['\uA74E'] },
            { 'base': 'OU', 'letters': ['\u0222'] },
            { 'base': 'OE', 'letters': ['\u008C', '\u0152'] },
            { 'base': 'oe', 'letters': ['\u009C', '\u0153'] },
            {
                'base': 'P',
                'letters': [
                    '\u0050', '\u24C5', '\uFF30', '\u1E54', '\u1E56', '\u01A4', '\u2C63', '\uA750', '\uA752',
                    '\uA754'
                ]
            },
            { 'base': 'Q', 'letters': ['\u0051', '\u24C6', '\uFF31', '\uA756', '\uA758', '\u024A'] },
            {
                'base': 'R',
                'letters': [
                    '\u0052', '\u24C7', '\uFF32', '\u0154', '\u1E58', '\u0158', '\u0210', '\u0212', '\u1E5A',
                    '\u1E5C', '\u0156', '\u1E5E', '\u024C', '\u2C64', '\uA75A', '\uA7A6', '\uA782'
                ]
            },
            {
                'base': 'S',
                'letters': [
                    '\u0053', '\u24C8', '\uFF33', '\u1E9E', '\u015A', '\u1E64', '\u015C', '\u1E60', '\u0160',
                    '\u1E66', '\u1E62', '\u1E68', '\u0218', '\u015E', '\u2C7E', '\uA7A8', '\uA784'
                ]
            },
            {
                'base': 'T',
                'letters': [
                    '\u0054', '\u24C9', '\uFF34', '\u1E6A', '\u0164', '\u1E6C', '\u021A', '\u0162', '\u1E70',
                    '\u1E6E', '\u0166', '\u01AC', '\u01AE', '\u023E', '\uA786'
                ]
            },
            { 'base': 'TZ', 'letters': ['\uA728'] },
            {
                'base': 'U',
                'letters': [
                    '\u0055', '\u24CA', '\uFF35', '\u00D9', '\u00DA', '\u00DB', '\u0168', '\u1E78', '\u016A',
                    '\u1E7A', '\u016C', '\u00DC', '\u01DB', '\u01D7', '\u01D5', '\u01D9', '\u1EE6', '\u016E',
                    '\u0170', '\u01D3', '\u0214', '\u0216', '\u01AF', '\u1EEA', '\u1EE8', '\u1EEE', '\u1EEC',
                    '\u1EF0', '\u1EE4', '\u1E72', '\u0172', '\u1E76', '\u1E74', '\u0244'
                ]
            },
            {
                'base': 'V',
                'letters': ['\u0056', '\u24CB', '\uFF36', '\u1E7C', '\u1E7E', '\u01B2', '\uA75E', '\u0245']
            },
            { 'base': 'VY', 'letters': ['\uA760'] },
            {
                'base': 'W',
                'letters': [
                    '\u0057', '\u24CC', '\uFF37', '\u1E80', '\u1E82', '\u0174', '\u1E86', '\u1E84', '\u1E88',
                    '\u2C72'
                ]
            },
            { 'base': 'X', 'letters': ['\u0058', '\u24CD', '\uFF38', '\u1E8A', '\u1E8C'] },
            {
                'base': 'Y',
                'letters': [
                    '\u0059', '\u24CE', '\uFF39', '\u1EF2', '\u00DD', '\u0176', '\u1EF8', '\u0232', '\u1E8E',
                    '\u0178', '\u1EF6', '\u1EF4', '\u01B3', '\u024E', '\u1EFE'
                ]
            },
            {
                'base': 'Z',
                'letters': [
                    '\u005A', '\u24CF', '\uFF3A', '\u0179', '\u1E90', '\u017B', '\u017D', '\u1E92', '\u1E94',
                    '\u01B5', '\u0224', '\u2C7F', '\u2C6B', '\uA762'
                ]
            },
            {
                'base': 'a',
                'letters': [
                    '\u0061', '\u24D0', '\uFF41', '\u1E9A', '\u00E0', '\u00E1', '\u00E2', '\u1EA7', '\u1EA5',
                    '\u1EAB', '\u1EA9', '\u00E3', '\u0101', '\u0103', '\u1EB1', '\u1EAF', '\u1EB5', '\u1EB3',
                    '\u0227', '\u01E1', '\u00E4', '\u01DF', '\u1EA3', '\u00E5', '\u01FB', '\u01CE', '\u0201',
                    '\u0203', '\u1EA1', '\u1EAD', '\u1EB7', '\u1E01', '\u0105', '\u2C65', '\u0250'
                ]
            },
            { 'base': 'aa', 'letters': ['\uA733'] },
            { 'base': 'ae', 'letters': ['\u00E6', '\u01FD', '\u01E3'] },
            { 'base': 'ao', 'letters': ['\uA735'] },
            { 'base': 'au', 'letters': ['\uA737'] },
            { 'base': 'av', 'letters': ['\uA739', '\uA73B'] },
            { 'base': 'ay', 'letters': ['\uA73D'] },
            {
                'base': 'b',
                'letters': [
                    '\u0062', '\u24D1', '\uFF42', '\u1E03', '\u1E05', '\u1E07', '\u0180', '\u0183', '\u0253'
                ]
            },
            {
                'base': 'c',
                'letters': [
                    '\u0063', '\u24D2', '\uFF43', '\u0107', '\u0109', '\u010B', '\u010D', '\u00E7', '\u1E09',
                    '\u0188', '\u023C', '\uA73F', '\u2184'
                ]
            },
            {
                'base': 'd',
                'letters': [
                    '\u0064', '\u24D3', '\uFF44', '\u1E0B', '\u010F', '\u1E0D', '\u1E11', '\u1E13', '\u1E0F',
                    '\u0111', '\u018C', '\u0256', '\u0257', '\uA77A'
                ]
            },
            { 'base': 'dz', 'letters': ['\u01F3', '\u01C6'] },
            {
                'base': 'e',
                'letters': [
                    '\u0065', '\u24D4', '\uFF45', '\u00E8', '\u00E9', '\u00EA', '\u1EC1', '\u1EBF',
                    '\u1EC5', '\u1EC3', '\u1EBD', '\u0113', '\u1E15', '\u1E17', '\u0115', '\u0117',
                    '\u00EB', '\u1EBB', '\u011B', '\u0205', '\u0207', '\u1EB9', '\u1EC7', '\u0229',
                    '\u1E1D', '\u0119', '\u1E19', '\u1E1B', '\u0247', '\u025B', '\u01DD'
                ]
            },
            { 'base': 'f', 'letters': ['\u0066', '\u24D5', '\uFF46', '\u1E1F', '\u0192', '\uA77C'] },
            {
                'base': 'g',
                'letters': [
                    '\u0067', '\u24D6', '\uFF47', '\u01F5', '\u011D', '\u1E21', '\u011F', '\u0121', '\u01E7',
                    '\u0123', '\u01E5', '\u0260', '\uA7A1', '\u1D79', '\uA77F'
                ]
            },
            {
                'base': 'h',
                'letters': [
                    '\u0068', '\u24D7', '\uFF48', '\u0125', '\u1E23', '\u1E27', '\u021F', '\u1E25', '\u1E29',
                    '\u1E2B', '\u1E96', '\u0127', '\u2C68', '\u2C76', '\u0265'
                ]
            },
            { 'base': 'hv', 'letters': ['\u0195'] },
            {
                'base': 'i',
                'letters': [
                    '\u0069', '\u24D8', '\uFF49', '\u00EC', '\u00ED', '\u00EE', '\u0129',
                    '\u012B', '\u012D', '\u00EF', '\u1E2F', '\u1EC9', '\u01D0', '\u0209',
                    '\u020B', '\u1ECB', '\u012F', '\u1E2D', '\u0268', '\u0131'
                ]
            },
            { 'base': 'j', 'letters': ['\u006A', '\u24D9', '\uFF4A', '\u0135', '\u01F0', '\u0249'] },
            {
                'base': 'k',
                'letters': [
                    '\u006B', '\u24DA', '\uFF4B', '\u1E31', '\u01E9', '\u1E33', '\u0137', '\u1E35', '\u0199',
                    '\u2C6A', '\uA741', '\uA743', '\uA745', '\uA7A3'
                ]
            },
            {
                'base': 'l',
                'letters': [
                    '\u006C', '\u24DB', '\uFF4C', '\u0140', '\u013A', '\u013E', '\u1E37', '\u1E39', '\u013C',
                    '\u1E3D', '\u1E3B', '\u017F', '\u0142', '\u019A', '\u026B', '\u2C61', '\uA749', '\uA781',
                    '\uA747'
                ]
            },
            { 'base': 'lj', 'letters': ['\u01C9'] },
            {
                'base': 'm',
                'letters': ['\u006D', '\u24DC', '\uFF4D', '\u1E3F', '\u1E41', '\u1E43', '\u0271', '\u026F']
            },
            {
                'base': 'n',
                'letters': [
                    '\u006E', '\u24DD', '\uFF4E', '\u01F9', '\u0144', '\u00F1', '\u1E45', '\u0148', '\u1E47',
                    '\u0146', '\u1E4B', '\u1E49', '\u019E', '\u0272', '\u0149', '\uA791', '\uA7A5'
                ]
            },
            { 'base': 'nj', 'letters': ['\u01CC'] },
            {
                'base': 'o',
                'letters': [
                    '\u006F', '\u24DE', '\uFF4F', '\u00F2', '\u00F3', '\u00F4', '\u1ED3', '\u1ED1', '\u1ED7',
                    '\u1ED5', '\u00F5', '\u1E4D', '\u022D', '\u1E4F', '\u014D', '\u1E51', '\u1E53', '\u014F',
                    '\u022F', '\u0231', '\u00F6', '\u022B', '\u1ECF', '\u0151', '\u01D2', '\u020D', '\u020F',
                    '\u01A1', '\u1EDD', '\u1EDB', '\u1EE1', '\u1EDF', '\u1EE3', '\u1ECD', '\u1ED9', '\u01EB',
                    '\u01ED', '\u00F8', '\u01FF', '\u0254', '\uA74B', '\uA74D', '\u0275'
                ]
            },
            { 'base': 'oi', 'letters': ['\u01A3'] },
            { 'base': 'ou', 'letters': ['\u0223'] },
            { 'base': 'oo', 'letters': ['\uA74F'] },
            {
                'base': 'p',
                'letters': [
                    '\u0070', '\u24DF', '\uFF50', '\u1E55', '\u1E57', '\u01A5', '\u1D7D', '\uA751', '\uA753',
                    '\uA755'
                ]
            },
            { 'base': 'q', 'letters': ['\u0071', '\u24E0', '\uFF51', '\u024B', '\uA757', '\uA759'] },
            {
                'base': 'r',
                'letters': [
                    '\u0072', '\u24E1', '\uFF52', '\u0155', '\u1E59', '\u0159', '\u0211', '\u0213', '\u1E5B',
                    '\u1E5D', '\u0157', '\u1E5F', '\u024D', '\u027D', '\uA75B', '\uA7A7', '\uA783'
                ]
            },
            {
                'base': 's',
                'letters': [
                    '\u0073', '\u24E2', '\uFF53', '\u00DF', '\u015B', '\u1E65', '\u015D', '\u1E61', '\u0161',
                    '\u1E67', '\u1E63', '\u1E69', '\u0219', '\u015F', '\u023F', '\uA7A9', '\uA785', '\u1E9B'
                ]
            },
            {
                'base': 't',
                'letters': [
                    '\u0074', '\u24E3', '\uFF54', '\u1E6B', '\u1E97', '\u0165', '\u1E6D', '\u021B', '\u0163',
                    '\u1E71', '\u1E6F', '\u0167', '\u01AD', '\u0288', '\u2C66', '\uA787'
                ]
            },
            { 'base': 'tz', 'letters': ['\uA729'] },
            {
                'base': 'u',
                'letters': [
                    '\u0075', '\u24E4', '\uFF55', '\u00F9', '\u00FA', '\u00FB', '\u0169', '\u1E79', '\u016B',
                    '\u1E7B', '\u016D', '\u00FC', '\u01DC', '\u01D8', '\u01D6', '\u01DA', '\u1EE7', '\u016F',
                    '\u0171', '\u01D4', '\u0215', '\u0217', '\u01B0', '\u1EEB', '\u1EE9', '\u1EEF', '\u1EED',
                    '\u1EF1', '\u1EE5', '\u1E73', '\u0173', '\u1E77', '\u1E75', '\u0289'
                ]
            },
            {
                'base': 'v',
                'letters': ['\u0076', '\u24E5', '\uFF56', '\u1E7D', '\u1E7F', '\u028B', '\uA75F', '\u028C']
            },
            { 'base': 'vy', 'letters': ['\uA761'] },
            {
                'base': 'w',
                'letters': [
                    '\u0077', '\u24E6', '\uFF57', '\u1E81', '\u1E83', '\u0175', '\u1E87', '\u1E85', '\u1E98',
                    '\u1E89', '\u2C73'
                ]
            },
            { 'base': 'x', 'letters': ['\u0078', '\u24E7', '\uFF58', '\u1E8B', '\u1E8D'] },
            {
                'base': 'y',
                'letters': [
                    '\u0079', '\u24E8', '\uFF59', '\u1EF3', '\u00FD', '\u0177', '\u1EF9', '\u0233', '\u1E8F',
                    '\u00FF', '\u1EF7', '\u1E99', '\u1EF5', '\u01B4', '\u024F', '\u1EFF'
                ]
            },
            {
                'base': 'z',
                'letters': [
                    '\u007A', '\u24E9', '\uFF5A', '\u017A', '\u1E91', '\u017C', '\u017E', '\u1E93', '\u1E95',
                    '\u01B6', '\u0225', '\u0240', '\u2C6C', '\uA763'
                ]
            }
        ];
        this.diacriticsMap = {};
        for (let /** @type {?} */ i = 0; i < defaultDiacriticsRemovalap.length; i += 1) {
            let /** @type {?} */ letters = defaultDiacriticsRemovalap[i].letters;
            for (let /** @type {?} */ j = 0; j < letters.length; j += 1) {
                this.diacriticsMap[letters[j]] = defaultDiacriticsRemovalap[i].base;
            }
        }
    }
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return input.replace(/[^','\u0000-','\u007E]/g, a => this.diacriticsMap[a] || a);
    }
}
LatinizePipe.decorators = [
    { type: Pipe, args: [{ name: 'latinize' },] },
];
/** @nocollapse */
LatinizePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LeftPadPipe {
    /**
     * @param {?} input
     * @param {?} requiredLength
     * @param {?=} padChar
     * @return {?}
     */
    transform(input, requiredLength, padChar = ' ') {
        if (!isString(input) || input.length >= requiredLength)
            return input;
        const /** @type {?} */ diff = requiredLength - input.length;
        return `${pad(diff, padChar)}${input}`;
    }
}
LeftPadPipe.decorators = [
    { type: Pipe, args: [{ name: 'leftPad' },] },
];
/** @nocollapse */
LeftPadPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LeftTrimPipe {
    /**
     * @param {?} input
     * @param {?=} chars
     * @return {?}
     */
    transform(input, chars = '\\s') {
        return input.replace(new RegExp('^' + chars + '+'), '');
    }
}
LeftTrimPipe.decorators = [
    { type: Pipe, args: [{ name: 'ltrim' },] },
];
/** @nocollapse */
LeftTrimPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MatchPipe {
    /**
     * @param {?} input
     * @param {?=} pattern
     * @param {?=} flag
     * @return {?}
     */
    transform(input, pattern, flag) {
        return input.match(new RegExp(pattern, flag));
    }
}
MatchPipe.decorators = [
    { type: Pipe, args: [{ name: 'match' },] },
];
/** @nocollapse */
MatchPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PhonePipe {
    /**
     * @param {?} input
     * @param {?=} locale
     * @param {?=} showCountryCode
     * @return {?}
     */
    transform(input, locale = 'en-US', showCountryCode = false) {
        if (isNil(input) || !/^[a-zA-Z]{2}-[a-zA-Z]{2}$/.test(locale))
            return input;
        const /** @type {?} */ strInput = input.replace(/[^0-9]/g, '');
        const /** @type {?} */ splittedLocale = locale.split('-');
        const /** @type {?} */ formattedLocale = `${splittedLocale[0].toLowerCase()}-${splittedLocale[1].toUpperCase()}`;
        const /** @type {?} */ phoneObj = getPhone(formattedLocale);
        if (isNil(phoneObj) || strInput.length < phoneObj.minLength)
            return input;
        const /** @type {?} */ pattern = phoneObj.pattern;
        const /** @type {?} */ matches = strInput.match(pattern);
        let /** @type {?} */ formattedPhone = '';
        switch (formattedLocale) {
            case 'en-US':
            case 'pt-BR':
                formattedPhone = `(${matches[2]}) ${matches[3]}-${matches[4]}`;
                break;
            default:
                break;
        }
        if (showCountryCode) {
            formattedPhone = `${phoneObj.countryCode} ${formattedPhone}`;
        }
        return formattedPhone;
    }
}
PhonePipe.decorators = [
    { type: Pipe, args: [{ name: 'phone' },] },
];
/** @nocollapse */
PhonePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RepeatPipe {
    /**
     * @param {?} input
     * @param {?=} times
     * @param {?=} separator
     * @return {?}
     */
    transform(input, times = 1, separator = '') {
        let /** @type {?} */ ret = input;
        while (--times) {
            ret += separator + input;
        }
        return ret;
    }
}
RepeatPipe.decorators = [
    { type: Pipe, args: [{ name: 'repeat' },] },
];
/** @nocollapse */
RepeatPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RightPadPipe {
    /**
     * @param {?} input
     * @param {?} requiredLength
     * @param {?=} padChar
     * @return {?}
     */
    transform(input, requiredLength, padChar = ' ') {
        if (!isString(input) || input.length >= requiredLength)
            return input;
        const /** @type {?} */ diff = requiredLength - input.length;
        return `${input}${pad(diff, padChar)}`;
    }
}
RightPadPipe.decorators = [
    { type: Pipe, args: [{ name: 'rightPad' },] },
];
/** @nocollapse */
RightPadPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RightTrimPipe {
    /**
     * @param {?} input
     * @param {?=} chars
     * @return {?}
     */
    transform(input, chars = '\\s') {
        return input.replace(new RegExp(chars + '+$'), '');
    }
}
RightTrimPipe.decorators = [
    { type: Pipe, args: [{ name: 'rtrim' },] },
];
/** @nocollapse */
RightTrimPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SlugifyPipe {
    /**
     * @param {?} input
     * @param {?=} sub
     * @return {?}
     */
    transform(input, sub = '-') {
        return input.toLowerCase().replace(/\s+/g, sub);
    }
}
SlugifyPipe.decorators = [
    { type: Pipe, args: [{ name: 'slugify' },] },
];
/** @nocollapse */
SlugifyPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SplitPipe {
    /**
     * @param {?} input
     * @param {?=} separator
     * @param {?=} limit
     * @return {?}
     */
    transform(input, separator = ' ', limit) {
        return !isString(input) ? input : input.split(separator, limit);
    }
}
SplitPipe.decorators = [
    { type: Pipe, args: [{ name: 'split' },] },
];
/** @nocollapse */
SplitPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class StartsWithPipe {
    /**
     * @param {?} input
     * @param {?=} ends
     * @param {?=} csensitive
     * @return {?}
     */
    transform(input, ends, csensitive = false) {
        if (ends === '') {
            return true;
        }
        if (!csensitive) {
            input = input.toLowerCase();
            ends = ends.toLowerCase();
        }
        return input.substring(0, ends.length) === ends;
    }
}
StartsWithPipe.decorators = [
    { type: Pipe, args: [{ name: 'startsWith' },] },
];
/** @nocollapse */
StartsWithPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class StringularPipe {
    /**
     * @param {?} template
     * @param {...?} args
     * @return {?}
     */
    transform(template, ...args) {
        return template.replace(/{(\d+)}/g, (match, number) => {
            return isUndefined(args[number]) ? match : args[number];
        });
    }
}
StringularPipe.decorators = [
    { type: Pipe, args: [{ name: 'stringular' },] },
];
/** @nocollapse */
StringularPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class StripTagsPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return input.replace(/<\S[^><]*>/g, '');
    }
}
StripTagsPipe.decorators = [
    { type: Pipe, args: [{ name: 'stripTags' },] },
];
/** @nocollapse */
StripTagsPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TestPipe {
    /**
     * @param {?} input
     * @param {?=} pattern
     * @param {?=} flag
     * @return {?}
     */
    transform(input, pattern, flag) {
        return new RegExp(pattern, flag).test(input);
    }
}
TestPipe.decorators = [
    { type: Pipe, args: [{ name: 'test' },] },
];
/** @nocollapse */
TestPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TitleizePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return input.split(' ')
            .map(w => w.charAt(0).toUpperCase() + w.substring(1).toLowerCase())
            .join(' ');
    }
}
TitleizePipe.decorators = [
    { type: Pipe, args: [{ name: 'titleize' },] },
];
/** @nocollapse */
TitleizePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TrimPipe {
    /**
     * @param {?} input
     * @param {?=} chars
     * @return {?}
     */
    transform(input, chars = '\\s') {
        return input.replace(new RegExp('^' + chars + '+|' + chars + '+$', 'g'), '');
    }
}
TrimPipe.decorators = [
    { type: Pipe, args: [{ name: 'trim' },] },
];
/** @nocollapse */
TrimPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TruncatePipe {
    /**
     * @param {?} input
     * @param {?=} length
     * @param {?=} suffix
     * @param {?=} preserve
     * @return {?}
     */
    transform(input, length, suffix = '', preserve = false) {
        if (isUndefined(length) || length >= input.length) {
            return input;
        }
        return input.substring(0, preserve ?
            (input.indexOf(' ', length) === -1 ? input.length : input.indexOf(' ', length)) :
            length) +
            suffix;
    }
}
TruncatePipe.decorators = [
    { type: Pipe, args: [{ name: 'truncate' },] },
];
/** @nocollapse */
TruncatePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class UcfirstPipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return input.substring(0, 1).toUpperCase() + input.substring(1);
    }
}
UcfirstPipe.decorators = [
    { type: Pipe, args: [{ name: 'ucfirst' },] },
];
/** @nocollapse */
UcfirstPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class UnderscorePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        if (!isString(input))
            return input;
        return input.replace(/\W/g, '').replace(/[A-Z]/g, (value, index) => index === 0 ? value.toLowerCase() : `_${value.toLowerCase()}`);
    }
}
UnderscorePipe.decorators = [
    { type: Pipe, args: [{ name: 'underscore' },] },
];
/** @nocollapse */
UnderscorePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class UriComponentEncodePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return encodeURIComponent(input);
    }
}
UriComponentEncodePipe.decorators = [
    { type: Pipe, args: [{ name: 'uriComponentEncode' },] },
];
/** @nocollapse */
UriComponentEncodePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class UriEncodePipe {
    /**
     * @param {?} input
     * @return {?}
     */
    transform(input) {
        return encodeURI(input);
    }
}
UriEncodePipe.decorators = [
    { type: Pipe, args: [{ name: 'uriEncode' },] },
];
/** @nocollapse */
UriEncodePipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class WrapPipe {
    /**
     * @param {?} input
     * @param {?=} wrap
     * @param {?=} ends
     * @return {?}
     */
    transform(input, wrap = '', ends = '') {
        return '' + wrap + input + (ends || wrap);
    }
}
WrapPipe.decorators = [
    { type: Pipe, args: [{ name: 'wrap' },] },
];
/** @nocollapse */
WrapPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class StringPipesModule {
}
StringPipesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    CamelizePipe,
                    CenterPadPipe,
                    EndsWithPipe,
                    LatinizePipe,
                    LeftPadPipe,
                    LeftTrimPipe,
                    MatchPipe,
                    PhonePipe,
                    RepeatPipe,
                    RightPadPipe,
                    RightTrimPipe,
                    SlugifyPipe,
                    SplitPipe,
                    StartsWithPipe,
                    StringularPipe,
                    StripTagsPipe,
                    TestPipe,
                    TitleizePipe,
                    TrimPipe,
                    TruncatePipe,
                    UcfirstPipe,
                    UnderscorePipe,
                    UriComponentEncodePipe,
                    UriEncodePipe,
                    WrapPipe
                ],
                exports: [
                    CamelizePipe,
                    CenterPadPipe,
                    EndsWithPipe,
                    LatinizePipe,
                    LeftPadPipe,
                    LeftTrimPipe,
                    MatchPipe,
                    PhonePipe,
                    RepeatPipe,
                    RightPadPipe,
                    RightTrimPipe,
                    SlugifyPipe,
                    SplitPipe,
                    StartsWithPipe,
                    StringularPipe,
                    StripTagsPipe,
                    TestPipe,
                    TitleizePipe,
                    TrimPipe,
                    TruncatePipe,
                    UcfirstPipe,
                    UnderscorePipe,
                    UriComponentEncodePipe,
                    UriEncodePipe,
                    WrapPipe
                ]
            },] },
];
/** @nocollapse */
StringPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgPipesModule {
}
NgPipesModule.decorators = [
    { type: NgModule, args: [{
                exports: [
                    BooleanPipesModule, CollectionPipesModule, MathPipesModule, ObjectPipesModule, StringPipesModule
                ]
            },] },
];
/** @nocollapse */
NgPipesModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { NgPipesModule, BooleanPipesModule, IsArrayPipe, IsDefinedPipe, IsEqualToPipe, IsFunctionPipe, IsGreaterThanOrEqualToPipe, IsGreaterThanPipe, IsIdenticalToPipe, IsLessThanOrEqualToPipe, IsLessThanPipe, IsNilPipe, IsNotEqualToPipe, IsNotIdenticalToPipe, IsNullPipe, IsNumberPipe, IsObjectPipe, IsStringPipe, IsUndefinedPipe, CollectionPipesModule, AfterWherePipe, AfterPipe, BeforeWherePipe, BeforePipe, ChunkByPipe, ConcatPipe, ContainsPipe, CountByPipe, DefaultsPipe, EveryPipe, FilterByPipe, FirstPipe, FlattenPipe, FuzzyByPipe, FuzzyPipe, GroupByPipe, IsEmptyPipe, JoinPipe, LastPipe, MapPipe, MeanPipe, OmitPipe, OrderByPipe, PickPipe, RangePipe, RemoveWithPipe, RemovePipe, ReversePipe, SearchFieldPipe, ToArrayPipe, UniqPipe, WherePipe, XORPipe, MathPipesModule, AbsPipe, ByteFmtPipe, CeilPipe, DegreesPipe, FloorPipe, KBFmtPipe, MaxPipe, MinPipe, PercentPipe, PowPipe, RadiansPipe, RadixPipe, RoundPipe, ShortFmtPipe, SqrtPipe, SumPipe, ObjectPipesModule, InvertPipe, KeysPipe, ValuesPipe, StringPipesModule, CamelizePipe, CenterPadPipe, EndsWithPipe, LatinizePipe, LeftPadPipe, LeftTrimPipe, MatchPipe, PhonePipe, RepeatPipe, RightPadPipe, RightTrimPipe, SlugifyPipe, SplitPipe, StartsWithPipe, StringularPipe, StripTagsPipe, TestPipe, TitleizePipe, TrimPipe, TruncatePipe, UcfirstPipe, UnderscorePipe, UriComponentEncodePipe, UriEncodePipe, WrapPipe };
//# sourceMappingURL=ng-pipes.js.map
